Crate composable_interceptor

Crate composable_interceptor 

Aspect-oriented programming for wasm components

Given a target WIT world, creates an interceptor component that wraps exported functions with before and after advice hooks. The interceptor, target, and advice components can then be composed using standard wasm component component model tooling, such as wac.

Entry points

Functions

create_from_component
Create an interceptor component from an existing component binary.
create_from_wit
Create an interceptor component for a WIT world.