Aspect-oriented programming for wasm components
Given a target WIT world, creates an interceptor component that wraps
exported functions with before and after advice hooks. The interceptor,
target, and advice components can then be composed using standard wasm
component component model tooling, such as wac.
Entry points
create_from_wit: create from a WIT path (no target component required)create_from_component: create from a target component .wasm file
Functions
- create_
from_ component - Create an interceptor component from an existing component binary.
- create_
from_ wit - Create an interceptor component for a WIT world.